@@ -329,8 +329,10 @@ typedef struct _HsaNodeProperties
     HSAuint32       VGPRSizePerCU;     // VGPR size in bytes per CU
     HSAuint32       SGPRSizePerCU;     // SGPR size in bytes per CU
 
+    HSAuint32       NumXcc;            // Number of XCC
     HSAuint32       KFDGpuID;          // GPU Hash ID generated by KFD
-    HSAuint8        Reserved[8];
+
+    HSAuint32       FamilyID;          // GPU family id
 } HsaNodeProperties;
 
 
